@@ -68,8 +68,7 @@ makeSizeAndDimList <- function(code, nodesToExtract, unrolledIndicesMatrix = NUL
             }
             thisCodeLength <- codeEndInds - codeStartInds + 1
             if(!all(thisCodeLength == thisCodeLength[1])){
-              print("Error: AD not currently supported for ragged arrays in model code")
-              browser()
+              stop("Error: AD not currently supported for ragged arrays in model code", call. = FALSE)
             }
             codeLength <- c(codeLength, thisCodeLength[1])
           }
@@ -216,11 +215,15 @@ Rname2CppName <- function(rName, colonsOK = TRUE) {
     ## which were largely redundant
     if (!is.character(rName))
         rName <- deparse(rName)
-    if( colonsOK)
+
+    if( colonsOK) {
+        # Substitute single colons but preserve double colons.
+        rName <- gsub('::', '_DOUBLE_COLON_', rName)
         rName <- gsub(':', 'to', rName)  # replace colons with 'to'
-    else
-        if(grepl(':', rName))
-            stop(paste0('trying to do name mashup on expression with colon (\':\') from ', rName))
+        rName <- gsub('_DOUBLE_COLON_', '::', rName)
+    } else if(grepl(':', rName)) {
+        stop(paste0('trying to do name mashup on expression with colon (\':\') from ', rName))
+    }
     rName <- gsub(' ', '', rName)
     rName <- gsub('\\.', '_dot_', rName) 
     rName <- gsub("\"", "_quote_", rName)
@@ -299,6 +302,24 @@ character2index <- function(thisChar){
 		stop("Error: too many :'s in index")
 }
 
+#' @export
+is.model <- function(obj, inputIsName = FALSE) {
+    if(inputIsName) obj <- get(obj)
+    return(inherits(obj, 'modelBaseClass'))
+}
+
+#' @export
+is.Rmodel <- function(obj, inputIsName = FALSE) {
+    if(inputIsName) obj <- get(obj)
+    return(inherits(obj, 'RmodelBaseClass'))
+}
+
+#' @export
+is.Cmodel <- function(obj, inputIsName = FALSE) {
+    if(inputIsName) obj <- get(obj)
+    return(inherits(obj, 'CmodelBaseClass'))
+}
+
 # extracts dimension from character vec of form such as c("double(0)", "integer(1)")
 ## getDimFromType <- function(text) {
 ##     sapply(parse(text = text), '[[', 2)
