@@ -1,5 +1,19 @@
-# used in altParams for dmnorm
-# this needs to be sourced after nimbleFunction() is defined, so can't be done in distributions_inputList.R
+
+## This is used in conjugacy definition for ddirch, to calculate 'contribution'
+## terms from dcat dependents.
+calc_dcatConjugacyContributions <- nimbleFunction(
+    name = 'calc_dcatConjugacyContributions',
+    run = function(ncat = double(0), value = double(0)) {
+        ans <- numeric(ncat)
+        ans[value] <- 1
+        return(ans)
+        returnType(double(1))
+    }
+)
+
+
+## used in altParams for dmnorm
+## this needs to be sourced after nimbleFunction() is defined, so can't be done in distributions_inputList.R
 calc_dmnormAltParams <- nimbleFunction(
     name = 'calc_dmnormAltParams',
     run = function(cholesky = double(2), prec_param = double(), return_prec = double()) {
@@ -18,8 +32,6 @@ calc_dmnormAltParams <- nimbleFunction(
 )
 
 
-
-
 ## used in conjugacy definition for dmnorm, to calculate 'contribution' terms;
 ## avoids unnecessary matrix multiplications, when 'coeff' is identity matrix
 calc_dmnormConjugacyContributions <- nimbleFunction(
@@ -47,8 +59,9 @@ calc_dmnormConjugacyContributions <- nimbleFunction(
     }
 )
 
-# used in altParams for dwish and dinvwish
-# this needs to be sourced after nimbleFunction() is defined, so can't be done in distributions_inputList.R
+
+## used in altParams for dwish and dinvwish
+## this needs to be sourced after nimbleFunction() is defined, so can't be done in distributions_inputList.R
 calc_dwishAltParams <- nimbleFunction(
     name = 'calc_dwishAltParams',
     run = function(cholesky = double(2), scale_param = double(), return_scale = double()) {
@@ -66,4 +79,3 @@ calc_dwishAltParams <- nimbleFunction(
     }
 )
 
-
