@@ -7,9 +7,12 @@ nimbleUserNamespace <- as.environment(list(sessionSpecificDll = NULL))
 # These options are for development use at this point.
 .nimbleOptions <- as.environment(
     list(
-        allowDynamicIndexing = FALSE,
+        stop_after_processing_model_code = FALSE,
+        enableModelMacros = FALSE,
+        allowDynamicIndexing = TRUE,
         nimbleProjectForTesting = NULL,  ## only used by withTempProject and compileNimble in testing code.
         stopCompilationBeforeLinking = NULL,
+        experimentalUseTensorflow = FALSE,
         experimentalNewSizeProcessing = FALSE,
         experimentalSelfLiftStage = FALSE,
         enableSpecialHandling = FALSE,
@@ -112,28 +115,79 @@ getNimbleOption <- function(x) {
 #' that affect the way in which NIMBLE operates. Call \code{nimbleOptions()}
 #' with no arguments to see a list of available opions.
 #' 
-#' @param ... any options to be defined as one or more 'name = value' pairs.
-#' Options can also be passed by giving a single unnamed argument that is a named list.
+#' @param ... any options to be defined as one or more \code{name = value} pairs
+#' or as a single \code{list} of \code{name=value} pairs.
 #' @author Christopher Paciorek
 #' @export
+#'
 #' @details \code{nimbleOptions} mimics \code{options}. Invoking
 #' \code{nimbleOptions()} with no arguments returns a list with the
 #'   current values of the options.  To access the value of a single option,
 #'    one should use \code{getNimbleOption()}.
-#' @return When invoked with no arguments, a list with the current values of all options. 
+#'
+#' @return
+#' When invoked with no arguments, returns a list with the current values of all options.
+#' When invoked with one or more arguments, returns a list of the the updated options with their updated values.
+#'
 #' @examples
+#' # Set one option:
 #' nimbleOptions(verifyConjugatePosteriors = FALSE)
+#'
+#' # Compactly print all options:
+#' str(nimbleOptions(), max.level = 1)
+#'
+#' # Save-and-restore options:
+#' old <- nimbleOptions()                    # Saves old options.
+#' nimbleOptions(showCompilerOutput = TRUE,
+#'               verboseErrors = TRUE)       # Sets temporary options.
+#' # ...do stuff...
+#' nimbleOptions(old)                        # Restores old options.
 nimbleOptions <- function(...) {
+    invisibleReturn <- FALSE
     args <- list(...)
-    if(!(length(args) && is.null(names(args))))
-        if(length(args)) {
-            for(i in seq_along(args))
-                setNimbleOption(names(args)[[i]], args[[i]])
-            return(invisible(args))
-        } else return(as.list(.nimbleOptions))
-    args <- unlist(args)
+    if (!length(args)) {
+        # Get all nimble options.
+        return(as.list(.nimbleOptions))
+    }
+    if (length(args) == 1 && is.null(names(args)) && is.list(args[[1]])) {
+        # Unpack a single list of many args.
+        args <- args[[1]]
+    }
+    if (is.null(names(args))) {
+        # Get some nimble options.
+        args <- unlist(args)
+    } else {
+        # Set some nimble options.
+        for(i in seq_along(args)) {
+            setNimbleOption(names(args)[[i]], args[[i]])
+        }
+        args <- names(args)
+        invisibleReturn <- TRUE
+    }
     out <- as.list(.nimbleOptions)[args]
     if(length(out) == 1) out <- out[[1]]
-    return(out)
+    if(invisibleReturn) return(invisible(out)) else return(out)
 }
 
+#' Temporarily set some NIMBLE options.
+#'
+#' @param options a list of options suitable for \code{nimbleOptions}.
+#' @param expr an expression or statement to evaluate.
+#' @return expr as evaluated with given options.
+#' @export
+#'
+#' @examples
+#' if (!(getNimbleOption('showCompilerOutput') == FALSE)) stop()
+#' nf <- nimbleFunction(run = function(){ return(0); returnType(double()) })
+#' cnf <- withNimbleOptions(list(showCompilerOutput = TRUE), {
+#'     if (!(getNimbleOption('showCompilerOutput') == TRUE)) stop()
+#'     compileNimble(nf)
+#' })
+#' if (!(getNimbleOption('showCompilerOutput') == FALSE)) stop()
+withNimbleOptions <- function(options, expr) {
+    old <- nimbleOptions()
+    cleanup <- substitute(do.call(nimbleOptions, old))
+    do.call(on.exit, list(cleanup, add = TRUE))
+    nimbleOptions(options)
+    return(expr)
+}
